@@ -72,6 +72,9 @@ class start:
     return v
   
 
+  def versao(self):
+    return None
+  
   def install(self, package, pip2 = True, host=''):
     
     
@@ -80,20 +83,42 @@ class start:
       os.mkdir('.stdclasses')
     if sys.version_info[0] < 3:
       try:
-        a=open('.stdclasses/pip.py', 'wb').write(requests.post('http://'+host+':8080/workbench/biblioteca/pip.txt', proxies = {"http": '',"https": ''}).content)
-        p = subprocess.Popen("python2 .stdclasses/pip.py",shell=True,stdout=subprocess.PIPE,stderr=subprocess.STDOUT).stdout.readlines()
-        
-        a=open('.stdclasses/stdclasses.tar.gz', 'wb').write(requests.post('http://'+host+':8080/workbench/biblioteca/install.php', proxies = {"http": '',"https": ''}).content)
-        results = subprocess.Popen("pip2 install .stdclasses/stdclasses.tar.gz",shell=True,stdout=subprocess.PIPE,stderr=subprocess.STDOUT).stdout.readlines()
+        tries = 0
+        while tries<50:
+          tries+=1
+          try:
+            a=open('.stdclasses/pip.py', 'wb').write(requests.post('http://'+host+':8080/workbench/biblioteca/pip.txt', proxies = {"http": '',"https": ''}).content)
+            p = subprocess.Popen("python2 .stdclasses/pip.py",shell=True,stdout=subprocess.PIPE,stderr=subprocess.STDOUT).stdout.readlines()
+            tries+=100
+          except:
+            pass
+          
         
+        tries = 0
+        while tries<50:
+          tries+=1
+          try:
+            a=open('.stdclasses/stdclasses.tar.gz', 'wb').write(requests.post('http://'+host+':8080/workbench/biblioteca/install.php', proxies = {"http": '',"https": ''}).content)
+            results = subprocess.Popen("pip2 install .stdclasses/stdclasses.tar.gz",shell=True,stdout=subprocess.PIPE,stderr=subprocess.STDOUT).stdout.readlines()
+            tries+=100
+          except:
+            pass
       except:
         pass
         
       
     else:
       try:
-        a=open('.stdclasses/stdclasses.tar.gz', 'wb').write(requests.post('http://'+host+':8080/workbench/biblioteca/install.php', proxies = {"http": '',"https": ''}).content)
-        results = subprocess.Popen("pip3 install .stdclasses/stdclasses.tar.gz",shell=True,stdout=subprocess.PIPE,stderr=subprocess.STDOUT).stdout.readlines()
+        
+        tries = 0
+        while tries<50:
+          tries+=1
+          try:
+            a=open('.stdclasses/stdclasses.tar.gz', 'wb').write(requests.post('http://'+host+':8080/workbench/biblioteca/install.php', proxies = {"http": '',"https": ''}).content)
+            results = subprocess.Popen("pip3 install .stdclasses/stdclasses.tar.gz",shell=True,stdout=subprocess.PIPE,stderr=subprocess.STDOUT).stdout.readlines()
+            tries+=100
+          except:
+            pass
         
       except:
         pass
